#!/usr/bin/env ruby

#  Copyright (C) 2006-2007 by Sergio Pistone
#  sergio_pistone@yahoo.com.ar
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation; either version 2 of the License, or
#  (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with this program; if not, write to the
#  Free Software Foundation, Inc.,
#  59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

require File.expand_path( File.dirname( __FILE__ ) + '/../utils/strings' )
require File.expand_path( File.dirname( __FILE__ ) + '/../utils/http' )
require File.expand_path( File.dirname( __FILE__ ) + '/../gui/gui' )
require File.expand_path( File.dirname( __FILE__ ) + '/../lyrics_Lyriki' )

def convert_page!( page, correct_case=false )
	if ( correct_case )
		page.gsub!( /(\s*\|\s*album\s*=\s*)([^\n]+)/ ) { $1 + Strings.titlecase!( $2, true ) }
		page.gsub!( /(\s*\|\s*artist\s*=\s*)([^\n]+)/ ) { $1 + Strings.titlecase!( $2, true ) }
	end
	convert_song_links!( page, correct_case )
	return page
end

def convert_song_links!( page, correct_case=false )
	# TODO some songs have the info param as <small>(VALUE)</small>
	page.gsub!( /\[\[([^:]+):([^\|]+)\|([^\]]+)\]\] *(<small>\s*\(?)?([0-9]+:[0-9]{2,2})?(\)?<\/small>)?/ ) do
		if ( correct_case )
			m1 = Strings.titlecase!( $1, true )
			m2 = Strings.titlecase!( $2, true )
			m3 = Strings.titlecase!( $3, true )
		else
			m1 = $1
			m2 = $2
			m3 = $3
		end
		if ( m2 != m3 )
			"{{song link|#{m1}|#{m2}|#{$5}|disp=#{m3}}}"
		elsif ( $5 && ! $5.empty?() )
			"{{song link|#{m1}|#{m2}|#{$5}}}"
		else
			"{{song link|#{m1}|#{m2}}}"
		end
	end
	return page
end

lyriki = Lyriki.new()
if ( ! lyriki.login( ARGV[0], ARGV[1] ) )
	puts "Could not login to Lyriki\nExiting"
	exit 1
end

fetch_func = Proc.new do |url|
	artist, album, year = lyriki.parse_album_url( url )
	if ( artist == nil || album == nil || year == nil )
		nil
	else
		response, url = HTTP::fetch_page_get( lyriki.build_album_rawdata_url( artist, album, year ) )
		if ( response == nil || response.body() == nil )
			nil
		else
			response.body
		end
	end
end

fix_func = Proc.new do |page_content|
	convert_page!( String.new( page_content ), true )
end

submit_func = Proc.new do |url, page_content|
	lyriki.submit_page( url, page_content, summary='album fixer edit' )
end

GUI.set_toolkit_priority( ['qt3', 'qt4', 'gtk', 'tk'] )
GUI.show_wiki_fix_pages_dialog( {
	'site_name' => 'Lyriki',
	'title' => 'Album pages fixer',
	'fetch_func' => fetch_func,
	'fix_func' => fix_func,
	'submit_func' => submit_func
} )
