#  Copyright (C) 2007 by Sergio Pistone
#  sergio_pistone@yahoo.com.ar
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation; either version 2 of the License, or
#  (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with this program; if not, write to the
#  Free Software Foundation, Inc.,
#  59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

require 'test/unit/testsuite'
require 'test/unit/ui/console/testrunner'
require 'plugin_tests'

class PluginsTests

	def self.find_plugins()
		plugins = {}
		Dir.new( File.expand_path( File.dirname( __FILE__ ) + '/..' ) ).each() do |filename|
			filename = File.expand_path( File.dirname( __FILE__ ) + '/../' + filename )
			if ( File.file?( filename ) && (md = /\/lyrics_([A-Za-z_0-9]*)\.rb$/.match( filename )) )
				plugins[md[1]] = filename
			end
		end
		return plugins
	end

	def self.load_plugins( plugins )
		@plugins = []
		plugins.each() do |classname, filename|
			require( filename ? filename : File.expand_path( File.dirname( __FILE__ ) + "/../lyrics_#{classname}.rb" ) )
			classobj = eval( classname )
			@plugins << eval( "#{classname}.new()" )
		end
		@plugins.sort!() { |x,y| x.site_name() <=> y.site_name() }
	end

	def self.suite()
		suite = Test::Unit::TestSuite.new( 'Plugins Tests' )
		plugins = self.load_plugins( self.find_plugins() )
		log_file = "#{ENV['HOME']}/.wikilyrics.log"
		Logging.setup( log_file, 2000 )
		plugins.each() { |plugin| plugin.log_file = log_file }
		plugins.each() { |plugin| suite << PluginTests.build_suite( plugin ) }
		return suite
	end

end

Test::Unit::UI::Console::TestRunner.run( PluginsTests.suite() )
